.. _github-stats:

GitHub statistics for 3.7.4 (Nov 17, 2023)
==========================================

GitHub statistics for 2023/09/12 (tag: v3.7.3) - 2023/11/17

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 1 issues and merged 3 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/87?closed=1>`__

The following 3 authors contributed 10 commits.

* Elliott Sales de Andrade
* Kyle Sunden
* Thomas A Caswell

GitHub issues and pull requests:

Pull Requests (3):

* :ghpull:`27332`: Backport PR #27290 on branch v3.7.x (Ensure GIL while releasing buffer)
* :ghpull:`27340`: Fix CI on v3.7.x branch
* :ghpull:`27290`: Ensure GIL while releasing buffer

Issues (1):

* :ghissue:`27262`: [Bug]: Segmentation fault when resizing on Python 3.12 and MacOS 14


Previous GitHub statistics
--------------------------


.. toctree::
    :maxdepth: 1
    :glob:
    :reversed:

    prev_whats_new/github_stats_*
